"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthClientController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const loopback4_authorization_1 = require("loopback4-authorization");
const loopback4_authentication_1 = require("loopback4-authentication");
const core_1 = require("@sourceloop/core");
const baseUrl = '/auth-clients';
let AuthClientController = class AuthClientController {
    constructor(authClientRepository) {
        this.authClientRepository = authClientRepository;
    }
    async create(authClient) {
        return this.authClientRepository.create(authClient);
    }
    async count(where) {
        return this.authClientRepository.count(where);
    }
    async find(filter) {
        return this.authClientRepository.find(filter);
    }
    async updateAll(authClient, where) {
        return this.authClientRepository.updateAll(authClient, where);
    }
    async findById(id) {
        return this.authClientRepository.findById(id);
    }
    async updateById(id, authClient) {
        await this.authClientRepository.updateById(id, authClient);
    }
    async replaceById(id, authClient) {
        await this.authClientRepository.replaceById(id, authClient);
    }
    async deleteById(id) {
        await this.authClientRepository.deleteById(id);
    }
};
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ["NotAllowed" /* NotAllowed */] }),
    rest_1.post(baseUrl, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'AuthClient model instance',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: rest_1.getModelSchemaRef(models_1.AuthClient) } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.requestBody({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: rest_1.getModelSchemaRef(models_1.AuthClient, { exclude: ['id'] }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthClientController.prototype, "create", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ["NotAllowed" /* NotAllowed */] }),
    rest_1.get(`${baseUrl}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'AuthClient model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.query.object('where', rest_1.getWhereSchemaFor(models_1.AuthClient))),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthClientController.prototype, "count", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ["NotAllowed" /* NotAllowed */] }),
    rest_1.get(baseUrl, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Array of AuthClient model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { type: 'array', items: rest_1.getModelSchemaRef(models_1.AuthClient) },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.query.object('filter', rest_1.getFilterSchemaFor(models_1.AuthClient))),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthClientController.prototype, "find", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ["NotAllowed" /* NotAllowed */] }),
    rest_1.patch(baseUrl, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'AuthClient PATCH success count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.requestBody({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: rest_1.getModelSchemaRef(models_1.AuthClient, { partial: true }),
            },
        },
    })),
    tslib_1.__param(1, rest_1.param.query.object('where', rest_1.getWhereSchemaFor(models_1.AuthClient))),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.AuthClient, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthClientController.prototype, "updateAll", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ["NotAllowed" /* NotAllowed */] }),
    rest_1.get(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'AuthClient model instance',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: rest_1.getModelSchemaRef(models_1.AuthClient) } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.number('id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Number]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthClientController.prototype, "findById", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ["NotAllowed" /* NotAllowed */] }),
    rest_1.patch(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            '204': {
                description: 'AuthClient PATCH success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.number('id')),
    tslib_1.__param(1, rest_1.requestBody({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: rest_1.getModelSchemaRef(models_1.AuthClient, { partial: true }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Number, models_1.AuthClient]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthClientController.prototype, "updateById", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ["NotAllowed" /* NotAllowed */] }),
    rest_1.put(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            '204': {
                description: 'AuthClient PUT success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.number('id')),
    tslib_1.__param(1, rest_1.requestBody()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Number, models_1.AuthClient]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthClientController.prototype, "replaceById", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ["NotAllowed" /* NotAllowed */] }),
    rest_1.del(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            '204': {
                description: 'AuthClient DELETE success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.number('id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Number]),
    tslib_1.__metadata("design:returntype", Promise)
], AuthClientController.prototype, "deleteById", null);
AuthClientController = tslib_1.__decorate([
    tslib_1.__param(0, repository_1.repository(repositories_1.AuthClientRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.AuthClientRepository])
], AuthClientController);
exports.AuthClientController = AuthClientController;
//# sourceMappingURL=auth-client.controller.js.map