/// <reference types="express" />
import { Request, Response } from '@loopback/rest';
import { IAuthUserWithPermissions, ILogger, SuccessResponse } from '@sourceloop/core';
import { AuthClient } from '../../models';
import { CodeReaderFn, CodeWriterFn, JwtPayloadFn } from '../../providers';
import { AuthClientRepository, RefreshTokenRepository, RevokedTokenRepository, RoleRepository, UserLevelPermissionRepository, UserLevelResourceRepository, UserRepository, UserTenantRepository } from '../../repositories';
import { TenantConfigRepository } from '../../repositories/tenant-config.repository';
import { AuthRefreshTokenRequest, AuthTokenRequest, LoginRequest } from './';
import { AuthUser } from './models/auth-user.model';
import { ResetPassword } from './models/reset-password.dto';
import { TokenResponse } from './models/token-response.dto';
export declare class LoginController {
    private readonly client;
    private readonly user;
    authClientRepository: AuthClientRepository;
    userRepo: UserRepository;
    roleRepo: RoleRepository;
    utPermsRepo: UserLevelPermissionRepository;
    userResourcesRepository: UserLevelResourceRepository;
    userTenantRepo: UserTenantRepository;
    refreshTokenRepo: RefreshTokenRepository;
    revokedTokensRepo: RevokedTokenRepository;
    tenantConfigRepo: TenantConfigRepository;
    private readonly req;
    logger: ILogger;
    private readonly getJwtPayload;
    constructor(client: AuthClient | undefined, user: AuthUser | undefined, authClientRepository: AuthClientRepository, userRepo: UserRepository, roleRepo: RoleRepository, utPermsRepo: UserLevelPermissionRepository, userResourcesRepository: UserLevelResourceRepository, userTenantRepo: UserTenantRepository, refreshTokenRepo: RefreshTokenRepository, revokedTokensRepo: RevokedTokenRepository, tenantConfigRepo: TenantConfigRepository, req: Request, logger: ILogger, getJwtPayload: JwtPayloadFn);
    login(req: LoginRequest): Promise<{
        code: string;
    }>;
    loginWithClientUser(req: LoginRequest, deviceId?: string): Promise<TokenResponse>;
    getToken(req: AuthTokenRequest, codeReader: CodeReaderFn, deviceId?: string): Promise<TokenResponse>;
    exchangeToken(req: AuthRefreshTokenRequest, deviceId?: string): Promise<TokenResponse>;
    loginViaGoogle(clientId?: string, clientSecret?: string): Promise<void>;
    googleCallback(code: string, state: string, response: Response, googleCodeWriter: CodeWriterFn): Promise<void>;
    loginViaKeycloak(clientId?: string, clientSecret?: string): Promise<void>;
    keycloakCallback(code: string, state: string, response: Response, keycloackCodeWriter: CodeWriterFn): Promise<void>;
    resetPassword(req: ResetPassword, auth: string, currentUser: IAuthUserWithPermissions): Promise<SuccessResponse>;
    me(): Promise<AuthUser | undefined>;
    private createJWT;
}
