"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoginController = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const crypto_1 = require("crypto");
const jwt = tslib_1.__importStar(require("jsonwebtoken"));
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const moment_timezone_1 = tslib_1.__importDefault(require("moment-timezone"));
const url_1 = require("url");
const keys_1 = require("../../keys");
const providers_1 = require("../../providers");
const repositories_1 = require("../../repositories");
const tenant_config_repository_1 = require("../../repositories/tenant-config.repository");
const _1 = require("./");
const auth_user_model_1 = require("./models/auth-user.model");
const reset_password_dto_1 = require("./models/reset-password.dto");
const token_response_dto_1 = require("./models/token-response.dto");
const queryGen = (req) => {
    return {
        accessType: 'offline',
        state: Object.keys(req.query)
            .map(key => `${key}=${req.query[key]}`)
            .join('&'),
    };
};
const keycloakQueryGen = (req) => {
    return {
        state: Object.keys(req.query)
            .map(key => `${key}=${req.query[key]}`)
            .join('&'),
    };
};
const userAgentKey = 'user-agent';
let LoginController = class LoginController {
    constructor(client, user, authClientRepository, userRepo, roleRepo, utPermsRepo, userResourcesRepository, userTenantRepo, refreshTokenRepo, revokedTokensRepo, tenantConfigRepo, req, logger, getJwtPayload) {
        this.client = client;
        this.user = user;
        this.authClientRepository = authClientRepository;
        this.userRepo = userRepo;
        this.roleRepo = roleRepo;
        this.utPermsRepo = utPermsRepo;
        this.userResourcesRepository = userResourcesRepository;
        this.userTenantRepo = userTenantRepo;
        this.refreshTokenRepo = refreshTokenRepo;
        this.revokedTokensRepo = revokedTokensRepo;
        this.tenantConfigRepo = tenantConfigRepo;
        this.req = req;
        this.logger = logger;
        this.getJwtPayload = getJwtPayload;
    }
    async login(req) {
        var _a;
        const userStatus = await this.userTenantRepo.findOne({
            where: {
                userId: (_a = this.user) === null || _a === void 0 ? void 0 : _a.id,
            },
            fields: {
                status: true,
            },
        });
        if (!this.client || !this.user) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        else if (!req.client_secret) {
            throw new rest_1.HttpErrors.BadRequest("Client Secret Missing" /* ClientSecretMissing */);
        }
        else if ((userStatus === null || userStatus === void 0 ? void 0 : userStatus.status) === 0 /* REGISTERED */) {
            throw new rest_1.HttpErrors.BadRequest('User not active yet');
        }
        else {
            // Do nothing and move ahead
        }
        try {
            const codePayload = {
                clientId: req.client_id,
                userId: this.user.id,
            };
            const token = jwt.sign(codePayload, this.client.secret, {
                expiresIn: this.client.authCodeExpiration,
                audience: req.client_id,
                issuer: process.env.JWT_ISSUER,
                algorithm: 'HS256',
            });
            return {
                code: token,
            };
        }
        catch (error) {
            this.logger.error(error);
            throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* InvalidCredentials */);
        }
    }
    async loginWithClientUser(req, deviceId) {
        var _a, _b;
        const userStatus = await this.userTenantRepo.findOne({
            where: {
                userId: (_a = this.user) === null || _a === void 0 ? void 0 : _a.id,
            },
            fields: {
                status: true,
            },
        });
        if (!this.client || !this.user) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        else if (!this.user.authClientIds ||
            this.user.authClientIds.length === 0) {
            throw new rest_1.HttpErrors.UnprocessableEntity("Client User Missing" /* ClientUserMissing */);
        }
        else if (!req.client_secret) {
            throw new rest_1.HttpErrors.BadRequest("Client Secret Missing" /* ClientSecretMissing */);
        }
        else if ((userStatus === null || userStatus === void 0 ? void 0 : userStatus.status) === 0 /* REGISTERED */) {
            throw new rest_1.HttpErrors.BadRequest('Your Sign-Up request is in process');
        }
        else {
            // Do nothing and move ahead
        }
        try {
            const payload = {
                clientId: this.client.clientId,
                user: this.user,
            };
            if (((_b = payload.user) === null || _b === void 0 ? void 0 : _b.id) &&
                !(await this.userRepo.firstTimeUser(payload.user.id))) {
                await this.userRepo.updateLastLogin(payload.user.id);
            }
            return await this.createJWT(payload, this.client, {
                deviceId,
                userAgent: this.req.headers[userAgentKey],
            });
        }
        catch (error) {
            this.logger.error(error);
            throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* InvalidCredentials */);
        }
    }
    async getToken(req, codeReader, deviceId) {
        const authClient = await this.authClientRepository.findOne({
            where: {
                clientId: req.clientId,
            },
        });
        if (!authClient) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        try {
            const code = await codeReader(req.code);
            const payload = jwt.verify(code, authClient.secret, {
                audience: req.clientId,
                issuer: process.env.JWT_ISSUER,
                algorithms: ['HS256'],
            });
            if (payload.userId &&
                !(await this.userRepo.firstTimeUser(payload.userId))) {
                await this.userRepo.updateLastLogin(payload.userId);
            }
            return await this.createJWT(payload, authClient, {
                deviceId,
                userAgent: this.req.headers[userAgentKey],
            });
        }
        catch (error) {
            this.logger.error(error);
            if (error.name === 'TokenExpiredError') {
                throw new rest_1.HttpErrors.Unauthorized("Code Expired" /* CodeExpired */);
            }
            else if (rest_1.HttpErrors.HttpError.prototype.isPrototypeOf(error)) {
                throw error;
            }
            else {
                throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* InvalidCredentials */);
            }
        }
    }
    async exchangeToken(req, deviceId) {
        const refreshPayload = await this.refreshTokenRepo.get(req.refreshToken);
        if (!refreshPayload) {
            throw new rest_1.HttpErrors.Unauthorized("Token Expired" /* TokenExpired */);
        }
        const authClient = await this.authClientRepository.findOne({
            where: {
                clientId: refreshPayload.clientId,
            },
        });
        if (!authClient) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        await this.revokedTokensRepo.set(refreshPayload.accessToken, {
            token: refreshPayload.accessToken,
        });
        await this.refreshTokenRepo.delete(req.refreshToken);
        return this.createJWT({ clientId: refreshPayload.clientId, userId: refreshPayload.userId }, authClient, {
            deviceId,
            userAgent: this.req.headers[userAgentKey],
        });
    }
    async loginViaGoogle(clientId, clientSecret) { }
    async googleCallback(code, state, response, googleCodeWriter) {
        const clientId = new url_1.URLSearchParams(state).get('client_id');
        if (!clientId || !this.user) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        const client = await this.authClientRepository.findOne({
            where: {
                clientId,
            },
        });
        if (!client || !client.redirectUrl) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        try {
            const codePayload = {
                clientId,
                user: this.user,
            };
            const token = await googleCodeWriter(jwt.sign(codePayload, client.secret, {
                expiresIn: client.authCodeExpiration,
                audience: clientId,
                issuer: process.env.JWT_ISSUER,
                algorithm: 'HS256',
            }));
            response.redirect(`${client.redirectUrl}?code=${token}`);
        }
        catch (error) {
            this.logger.error(error);
            throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* InvalidCredentials */);
        }
    }
    async loginViaKeycloak(clientId, clientSecret) { }
    async keycloakCallback(code, state, response, keycloackCodeWriter) {
        const clientId = new url_1.URLSearchParams(state).get('client_id');
        if (!clientId || !this.user) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        const client = await this.authClientRepository.findOne({
            where: {
                clientId,
            },
        });
        if (!client || !client.redirectUrl) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* ClientInvalid */);
        }
        try {
            const codePayload = {
                clientId,
                user: this.user,
            };
            const token = await keycloackCodeWriter(jwt.sign(codePayload, client.secret, {
                expiresIn: client.authCodeExpiration,
                audience: clientId,
                issuer: process.env.JWT_ISSUER,
                algorithm: 'HS256',
            }));
            response.redirect(`${client.redirectUrl}?code=${token}`);
        }
        catch (error) {
            this.logger.error(error);
            throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* InvalidCredentials */);
        }
    }
    async resetPassword(req, auth, currentUser) {
        const token = auth === null || auth === void 0 ? void 0 : auth.replace(/bearer /i, '');
        if (!token || !req.refreshToken) {
            throw new rest_1.HttpErrors.UnprocessableEntity("TokenMissing" /* TokenMissing */);
        }
        const refreshTokenModel = await this.refreshTokenRepo.get(req.refreshToken);
        if (refreshTokenModel.accessToken !== token) {
            throw new rest_1.HttpErrors.Unauthorized("Token Invalid" /* TokenInvalid */);
        }
        if (refreshTokenModel.username !== req.username ||
            currentUser.username !== req.username) {
            throw new rest_1.HttpErrors.Forbidden("NotAllowedAccess" /* NotAllowedAccess */);
        }
        if (req.password && req.password.length <= 0) {
            throw new rest_1.HttpErrors.BadRequest("PasswordInvalid" /* PasswordInvalid */);
        }
        let changePasswordResponse;
        if (req.oldPassword) {
            changePasswordResponse = await this.userRepo.updatePassword(req.username, req.oldPassword, req.password);
        }
        else {
            changePasswordResponse = await this.userRepo.changePassword(req.username, req.password);
        }
        if (!changePasswordResponse) {
            throw new rest_1.HttpErrors.UnprocessableEntity('Unable to set password !');
        }
        const userTenant = await this.userTenantRepo.findOne({
            where: {
                userId: changePasswordResponse.id,
                tenantId: currentUser.tenantId,
            },
        });
        if (!userTenant) {
            throw new rest_1.HttpErrors.Unauthorized("UserInactive" /* UserInactive */);
        }
        if (userTenant.status && userTenant.status < 1 /* ACTIVE */) {
            await this.userRepo.userTenants(changePasswordResponse.id).patch({
                status: 1 /* ACTIVE */,
            });
        }
        await this.revokedTokensRepo.set(token, { token });
        await this.refreshTokenRepo.delete(req.refreshToken);
        return new core_1.SuccessResponse({
            success: true,
        });
    }
    async me() {
        if (!this.user) {
            throw new rest_1.HttpErrors.Unauthorized("Token Invalid" /* TokenInvalid */);
        }
        delete this.user.deviceInfo;
        return new auth_user_model_1.AuthUser(this.user);
    }
    async createJWT(payload, authClient, deviceInfo) {
        try {
            const size = 32;
            const ms = 1000;
            let user;
            if (payload.user) {
                user = payload.user;
            }
            else if (payload.userId) {
                user = await this.userRepo.findById(payload.userId, {
                    include: [
                        {
                            relation: 'defaultTenant',
                        },
                    ],
                });
            }
            else {
                // Do nothing and move ahead
            }
            if (!user) {
                throw new rest_1.HttpErrors.Unauthorized("UserDoesNotExist" /* UserDoesNotExist */);
            }
            const data = await this.getJwtPayload(user, authClient, deviceInfo);
            const accessToken = jwt.sign(data, process.env.JWT_SECRET, {
                expiresIn: authClient.accessTokenExpiration,
                issuer: process.env.JWT_ISSUER,
                algorithm: 'HS256',
            });
            const refreshToken = crypto_1.randomBytes(size).toString('hex');
            // Set refresh token into redis for later verification
            await this.refreshTokenRepo.set(refreshToken, {
                clientId: authClient.clientId,
                userId: user.id,
                username: user.username,
                accessToken,
            }, { ttl: authClient.refreshTokenExpiration * ms });
            return new token_response_dto_1.TokenResponse({
                accessToken,
                refreshToken,
                expires: moment_timezone_1.default()
                    .add(authClient.accessTokenExpiration, 's')
                    .toDate()
                    .getTime(),
            });
        }
        catch (error) {
            this.logger.error(error);
            if (rest_1.HttpErrors.HttpError.prototype.isPrototypeOf(error)) {
                throw error;
            }
            else {
                throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* InvalidCredentials */);
            }
        }
    }
};
tslib_1.__decorate([
    loopback4_authentication_1.authenticateClient("client-password" /* CLIENT_PASSWORD */),
    loopback4_authentication_1.authenticate("local" /* LOCAL */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.post('/auth/login', {
        description: 'Gets you the code that will be used for getting token (webapps)',
        responses: {
            [200 /* OK */]: {
                description: 'Auth Code',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: Object,
                },
            },
            ...core_1.ErrorCodes,
        },
    }),
    tslib_1.__param(0, rest_1.requestBody()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [_1.LoginRequest]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "login", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticateClient("client-password" /* CLIENT_PASSWORD */),
    loopback4_authentication_1.authenticate("OAuth2 resource owner grant" /* OAUTH2_RESOURCE_OWNER_GRANT */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.post('/auth/login-token', {
        description: 'Gets you refresh token and access token in one hit. (mobile app)',
        responses: {
            [200 /* OK */]: {
                description: 'Token Response Model',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { 'x-ts-type': token_response_dto_1.TokenResponse },
                    },
                },
            },
            ...core_1.ErrorCodes,
        },
    }),
    tslib_1.__param(0, rest_1.requestBody()),
    tslib_1.__param(1, rest_1.param.header.string('device_id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [_1.LoginRequest, String]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "loginWithClientUser", null);
tslib_1.__decorate([
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.post('/auth/token', {
        description: ' Send the code received from the above api and this api will send you refresh token and access token (webapps)',
        responses: {
            [200 /* OK */]: {
                description: 'Token Response',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { 'x-ts-type': token_response_dto_1.TokenResponse },
                    },
                },
            },
            ...core_1.ErrorCodes,
        },
    }),
    tslib_1.__param(0, rest_1.requestBody()),
    tslib_1.__param(1, context_1.inject(providers_1.AuthCodeBindings.CODEREADER_PROVIDER)),
    tslib_1.__param(2, rest_1.param.header.string('device_id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [_1.AuthTokenRequest, Function, String]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "getToken", null);
tslib_1.__decorate([
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.post('/auth/token-refresh', {
        description: ' Gets you a new access and refresh token once your access token is expired. (both mobile and web)\n',
        responses: {
            [200 /* OK */]: {
                description: 'New Token Response',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { 'x-ts-type': token_response_dto_1.TokenResponse },
                    },
                },
            },
            ...core_1.ErrorCodes,
        },
    }),
    tslib_1.__param(0, rest_1.requestBody()),
    tslib_1.__param(1, rest_1.param.header.string('device_id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [_1.AuthRefreshTokenRequest, String]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "exchangeToken", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticateClient("client-password" /* CLIENT_PASSWORD */),
    loopback4_authentication_1.authenticate("Google Oauth 2.0" /* GOOGLE_OAUTH2 */, {
        accessType: 'offline',
        scope: ['profile', 'email'],
        authorizationURL: process.env.GOOGLE_AUTH_URL,
        callbackURL: process.env.GOOGLE_AUTH_CALLBACK_URL,
        clientID: process.env.GOOGLE_AUTH_CLIENT_ID,
        clientSecret: process.env.GOOGLE_AUTH_CLIENT_SECRET,
        tokenURL: process.env.GOOGLE_AUTH_TOKEN_URL,
    }, queryGen),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get('/auth/google', {
        responses: {
            [200 /* OK */]: {
                description: 'Google Token Response',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { 'x-ts-type': token_response_dto_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.query.string('client_id')),
    tslib_1.__param(1, rest_1.param.query.string('client_secret')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "loginViaGoogle", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("Google Oauth 2.0" /* GOOGLE_OAUTH2 */, {
        accessType: 'offline',
        scope: ['profile', 'email'],
        authorizationURL: process.env.GOOGLE_AUTH_URL,
        callbackURL: process.env.GOOGLE_AUTH_CALLBACK_URL,
        clientID: process.env.GOOGLE_AUTH_CLIENT_ID,
        clientSecret: process.env.GOOGLE_AUTH_CLIENT_SECRET,
        tokenURL: process.env.GOOGLE_AUTH_TOKEN_URL,
    }, queryGen),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get('/auth/google-auth-redirect', {
        responses: {
            [200 /* OK */]: {
                description: 'Google Redirect Token Response',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { 'x-ts-type': token_response_dto_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.query.string('code')),
    tslib_1.__param(1, rest_1.param.query.string('state')),
    tslib_1.__param(2, context_1.inject(rest_1.RestBindings.Http.RESPONSE)),
    tslib_1.__param(3, context_1.inject(providers_1.AuthCodeBindings.CODEWRITER_PROVIDER)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String, Object, Function]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "googleCallback", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticateClient("client-password" /* CLIENT_PASSWORD */),
    loopback4_authentication_1.authenticate("keycloak" /* KEYCLOAK */, {
        host: process.env.KEYCLOAK_HOST,
        realm: process.env.KEYCLOAK_REALM,
        clientID: process.env.KEYCLOAK_CLIENT_ID,
        clientSecret: process.env.KEYCLOAK_CLIENT_SECRET,
        callbackURL: process.env.KEYCLOAK_CALLBACK_URL,
        authorizationURL: `${process.env.KEYCLOAK_HOST}/auth/realms/${process.env.KEYCLOAK_REALM}/protocol/openid-connect/auth`,
        tokenURL: `${process.env.KEYCLOAK_HOST}/auth/realms/${process.env.KEYCLOAK_REALM}/protocol/openid-connect/token`,
        userInfoURL: `${process.env.KEYCLOAK_HOST}/auth/realms/${process.env.KEYCLOAK_REALM}/protocol/openid-connect/userinfo`,
    }, keycloakQueryGen),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get('/auth/keycloak', {
        responses: {
            [200 /* OK */]: {
                description: 'Keycloak Token Response',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { 'x-ts-type': token_response_dto_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.query.string('client_id')),
    tslib_1.__param(1, rest_1.param.query.string('client_secret')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "loginViaKeycloak", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("keycloak" /* KEYCLOAK */, {
        host: process.env.KEYCLOAK_HOST,
        realm: process.env.KEYCLOAK_REALM,
        clientID: process.env.KEYCLOAK_CLIENT_ID,
        clientSecret: process.env.KEYCLOAK_CLIENT_SECRET,
        callbackURL: process.env.KEYCLOAK_CALLBACK_URL,
        authorizationURL: `${process.env.KEYCLOAK_HOST}/auth/realms/${process.env.KEYCLOAK_REALM}/protocol/openid-connect/auth`,
        tokenURL: `${process.env.KEYCLOAK_HOST}/auth/realms/${process.env.KEYCLOAK_REALM}/protocol/openid-connect/token`,
        userInfoURL: `${process.env.KEYCLOAK_HOST}/auth/realms/${process.env.KEYCLOAK_REALM}/protocol/openid-connect/userinfo`,
    }, keycloakQueryGen),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get('/auth/keycloak-auth-redirect', {
        responses: {
            [200 /* OK */]: {
                description: 'Keycloak Redirect Token Response',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: { 'x-ts-type': token_response_dto_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.query.string('code')),
    tslib_1.__param(1, rest_1.param.query.string('state')),
    tslib_1.__param(2, context_1.inject(rest_1.RestBindings.Http.RESPONSE)),
    tslib_1.__param(3, context_1.inject(providers_1.AuthCodeBindings.CODEWRITER_PROVIDER)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String, Object, Function]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "keycloakCallback", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */, { passReqToCallback: true }),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.patch(`auth/change-password`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'If User password successfully changed.',
            },
        },
    }),
    tslib_1.__param(0, rest_1.requestBody({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: rest_1.getModelSchemaRef(reset_password_dto_1.ResetPassword, { partial: true }),
            },
        },
    })),
    tslib_1.__param(1, rest_1.param.header.string('Authorization')),
    tslib_1.__param(2, context_1.inject(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [reset_password_dto_1.ResetPassword, String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "resetPassword", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */, {
        passReqToCallback: true,
    }),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get('/auth/me', {
        security: core_1.OPERATION_SECURITY_SPEC,
        description: 'To get the user details',
        responses: {
            [200 /* OK */]: {
                description: 'User Object',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: auth_user_model_1.AuthUser,
                },
            },
            ...core_1.ErrorCodes,
        },
    }),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Promise)
], LoginController.prototype, "me", null);
LoginController = tslib_1.__decorate([
    tslib_1.__param(0, context_1.inject(loopback4_authentication_1.AuthenticationBindings.CURRENT_CLIENT)),
    tslib_1.__param(1, context_1.inject(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__param(2, repository_1.repository(repositories_1.AuthClientRepository)),
    tslib_1.__param(3, repository_1.repository(repositories_1.UserRepository)),
    tslib_1.__param(4, repository_1.repository(repositories_1.RoleRepository)),
    tslib_1.__param(5, repository_1.repository(repositories_1.UserLevelPermissionRepository)),
    tslib_1.__param(6, repository_1.repository(repositories_1.UserLevelResourceRepository)),
    tslib_1.__param(7, repository_1.repository(repositories_1.UserTenantRepository)),
    tslib_1.__param(8, repository_1.repository(repositories_1.RefreshTokenRepository)),
    tslib_1.__param(9, repository_1.repository(repositories_1.RevokedTokenRepository)),
    tslib_1.__param(10, repository_1.repository(tenant_config_repository_1.TenantConfigRepository)),
    tslib_1.__param(11, context_1.inject(rest_1.RestBindings.Http.REQUEST)),
    tslib_1.__param(12, context_1.inject(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(13, context_1.inject(keys_1.AuthServiceBindings.JWTPayloadProvider)),
    tslib_1.__metadata("design:paramtypes", [Object, Object, repositories_1.AuthClientRepository,
        repositories_1.UserRepository,
        repositories_1.RoleRepository,
        repositories_1.UserLevelPermissionRepository,
        repositories_1.UserLevelResourceRepository,
        repositories_1.UserTenantRepository,
        repositories_1.RefreshTokenRepository,
        repositories_1.RevokedTokenRepository,
        tenant_config_repository_1.TenantConfigRepository, Object, Object, Function])
], LoginController);
exports.LoginController = LoginController;
//# sourceMappingURL=login.controller.js.map